<nav class="mobile-tab-bar">
    <ul>
        <li {% if active_page == 'new-research' %}class="active"{% endif %} data-page="new-research">
            <a href="/">
                <i class="fas fa-search"></i>
                <span>Research</span>
            </a>
        </li>
        <li {% if active_page == 'history' %}class="active"{% endif %} data-page="history">
            <a href="{{ url_for('history.history_page') }}">
                <i class="fas fa-history"></i>
                <span>History</span>
            </a>
        </li>
        <li {% if active_page == 'news' %}class="active"{% endif %} data-page="news">
            <a href="{{ url_for('news.news_page') }}">
                <i class="fas fa-newspaper"></i>
                <span>News</span>
            </a>
        </li>
        <li {% if active_page == 'subscriptions' %}class="active"{% endif %} data-page="subscriptions">
            <a href="{{ url_for('news.subscriptions_page') }}">
                <i class="fas fa-bell"></i>
                <span>Subscriptions</span>
            </a>
        </li>
        <li {% if active_page == 'settings' %}class="active"{% endif %} data-page="settings">
            <a href="{{ url_for('settings.settings_page') }}">
                <i class="fas fa-cog"></i>
                <span>Settings</span>
            </a>
        </li>
    </ul>
</nav>
